antares.apps.flow.exceptions package — Antares 0.0.2 documentation

# antares.apps.flow.exceptions package

## Submodules

## antares.apps.flow.exceptions.flow_exception module

Created on Jul 12, 2016

@author: leobelen

exception `antares.apps.flow.exceptions.flow_exception.` `FlowException`(value)

  Bases: `Exception`

## antares.apps.flow.exceptions.invalid_status_exception module

Created on Jul 16, 2016

@author: leobelen

exception `antares.apps.flow.exceptions.invalid_status_exception.` `InvalidStatusException`(value)

  Bases: `Exception`

## antares.apps.flow.exceptions.invalid_xpdl_exception module

Created on Jul 5, 2016

@author: leobelen

exception `antares.apps.flow.exceptions.invalid_xpdl_exception.` `InvalidXPDLException`(value)

  Bases: `Exception`

## Module contents